package com.herpro.livedata;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;

import com.herpro.livedata.model.Category;

import java.util.HashMap;

public class CategoriesRepository {

    private static CategoriesRepository sInstance;

    // Indice simulador para autogeneración de IDs
    public static int autogeneratedId = 6;

    private final MutableLiveData<HashMap<Integer, Category>> observableCategories;
    private final HashMap<Integer, Category> dummyData;

    private CategoriesRepository() {
        // Inserción por defecto de datos
        dummyData = new HashMap<>();
        dummyData.put(1, new Category(1, "Alimentación"));
        dummyData.put(2, new Category(2, "Servicios"));
        dummyData.put(3, new Category(3, "Ropa"));
        dummyData.put(4, new Category(4, "Diversión"));
        dummyData.put(5, new Category(5, "Salud"));

        observableCategories = new MutableLiveData<>();
        observableCategories.setValue(dummyData);
    }

    public static CategoriesRepository getsInstance() {
        if (sInstance == null) {
            sInstance = new CategoriesRepository();
        }
        return sInstance;
    }

    public LiveData<Category> getCategory(int categoryId) {
        return new MutableLiveData<>(observableCategories.getValue().get(categoryId));
    }

    public void addCategory(Category category) {
        dummyData.put(category.getId(), category);
        observableCategories.setValue(dummyData);
        autogeneratedId++;
    }

    public void delete(int categoryId) {
        dummyData.remove(categoryId);
        observableCategories.setValue(dummyData);
    }

    public LiveData<HashMap<Integer, Category>> getCategories() {
        return observableCategories;
    }
}
